@@ -2,6 +2,7 @@
 
 /* eslint no-throw-literal: off */
 
+var sinon = require('sinon');
 var Mocha = require('../../lib/mocha');
 var Suite = Mocha.Suite;
 var Test = Mocha.Test;
@@ -29,6 +30,7 @@ describe('a test that throws', function () {
     uncaughtHandlers.forEach(function (listener) {
       process.on('uncaughtException', listener);
     });
+    sinon.restore(); 
   });
 
   describe('non-extensible', function () {
@@ -172,4 +174,35 @@ describe('a test that throws', function () {
       runner.run();
     });
   });
+
+  describe('stack', function() {
+    it('should include the stack when throwing async', function(done) {
+      var test = new Test('im async and throw null async', function(done2) {
+        process.nextTick(function throwError() {
+          throw new Error('test error');
+        });
+      });
+      suite.addTest(test);
+      runner = new Runner(suite);
+      sinon.stub(runner, 'fail');
+
+      runner.on(EVENT_RUN_END, function() {
+        try {
+          expect(runner.fail, 'to have all calls satisfying', [
+            expect.it('to be a', Runnable),
+            expect.it('to be an', Error).and('to satisfy', {
+              message: /test error/i,
+              stack: /throwError/i,
+              uncaught: true
+            })
+          ]).and('was called once');
+        } catch (err) {
+          return done(err);
+        }
+
+        done();
+      });
+      runner.run();
+    });
+  });
 });
